# WFSuite 1.0

WFSuite is a graphical and command-line toolkit for coded-mask-based X-ray wavefront sensing and phase reconstruction at synchrotron beamlines.


## Installation

We suggest creating a virtual environment with virtualenv or conda.
The program performs better with python 3.10+, and it has been tested up to python 3.13

To install it, run on a prompt of the target python environment: 

python -m pip install wf-suite

## Starting WFSuite

Open the GUI with:

python -m aps.wavefront_analysis Launcher

The launcher provides access to:

· Absolute Phase

· Relative Metrology

· Wavefront Sensor (opens automatically)

Please refer to the [user manual](User-Manual.pdf) in the home directory of this repository for details. 
